@@ -112,7 +112,7 @@ samp = data.frame(MASS::mvrnorm(n, mu = c(0, 0, 0),
    message("Power b1 = ", Power_b1)
    message("Power b2 = ", Power_b2)
    message("Proportion Rejecting None = ", PowerAll_R0)
-   message("Proportion Rejecting One = ", PowerAll_R1)
+   message("Proportion Rejecting Only One = ", PowerAll_R1)
    message("Power ALL (Proportion Rejecting All) = ", PowerAll_R2)
    result <- data.frame(matrix(ncol = 7))
    colnames(result) <- c( "n","Power R2", "Power b1", "Power b2",
@@ -209,8 +209,8 @@ samp = data.frame(MASS::mvrnorm(n, mu = c(0, 0, 0),
  message("Power b2 = ", Power_b2)
  message("Power b3 = ", Power_b3)
  message("Proportion Rejecting None = ", PowerAll_R0)
- message("Proportion Rejecting One = ", PowerAll_R1)
- message("Proportion Rejecting Two = ", PowerAll_R2)
+ message("Proportion Rejecting Only One = ", PowerAll_R1)
+ message("Proportion Rejecting Only Two = ", PowerAll_R2)
  message("Power ALL (Proportion Rejecting All) = ", PowerAll_R3)
  result <- data.frame(matrix(ncol = 9))
  colnames(result) <- c( "n","Power R2", "Power b1", "Power b2",
@@ -319,9 +319,9 @@ if (pred=="4")
  message("Power b3 = ", Power_b3)
  message("Power b4 = ", Power_b4)
  message("Proportion Rejecting None = ", PowerAll_R0)
- message("Proportion Rejecting One = ", PowerAll_R1)
- message("Proportion Rejecting Two = ", PowerAll_R2)
- message("Proportion Rejecting Three = ", PowerAll_R3)
+ message("Proportion Rejecting Only One = ", PowerAll_R1)
+ message("Proportion Rejecting Only Two = ", PowerAll_R2)
+ message("Proportion Rejecting Only Three = ", PowerAll_R3)
  message("Power ALL (Proportion Rejecting All) = ", PowerAll_R4)
  result <- data.frame(matrix(ncol = 11))
  colnames(result) <- c( "n","Power R2", "Power b1", "Power b2",
@@ -446,10 +446,10 @@ if (pred=="4")
    message("Power b4 = ", Power_b4)
    message("Power b5 = ", Power_b5)
    message("Proportion Rejecting None = ", PowerAll_R0)
-   message("Proportion Rejecting One = ", PowerAll_R1)
-   message("Proportion Rejecting Two = ", PowerAll_R2)
-   message("Proportion Rejecting Three = ", PowerAll_R3)
-   message("Proportion Rejecting Four = ", PowerAll_R4)
+   message("Proportion Rejecting Only One = ", PowerAll_R1)
+   message("Proportion Rejecting Only Two = ", PowerAll_R2)
+   message("Proportion Rejecting Only Three = ", PowerAll_R3)
+   message("Proportion Rejecting Only Four = ", PowerAll_R4)
    message("Power ALL (Proportion Rejecting All) = ", PowerAll_R5)
    result <- data.frame(matrix(ncol = 13))
    colnames(result) <- c( "n","Power R2", "Power b1", "Power b2",
